@@ -2,28 +2,27 @@
 
 _package_data = dict(
     full_package_name='ruamel.std.pathlib',
-    version_info=(0, 9, 0),
-    __version__='0.9.0',
+    version_info=(0, 9, 1),
+    __version__='0.9.1',
+    version_timestamp='2022-01-26 21:55:20',
     author='Anthon van der Neut',
     author_email='a.van.der.neut@ruamel.eu',
     since=2013,
     description='improvements over the standard pathlib module',
     entry_points=None,
     license='MIT License',
-    universal=True,
     tox=dict(env='*',),
-    python_requires='>=3.6',
+    python_requires='>=3',  # 3.7
     print_allowed=True,
 )
-# pathlib2 for 3.4 -> expanduser added
 
 version_info = _package_data['version_info']
 __version__ = _package_data['__version__']
 
 ###########
 
-import os       # NOQA
-import sys      # NOQA
+import os  # NOQA
+import sys  # NOQA
 import inspect  # NOQA
 import pathlib  # NOQA
 
@@ -137,9 +136,13 @@ pathlib.Path.copy = _copy
 
 # this is the times parameter of os.utime, taking int/float seconds (and not nanoseconds)
 if sys.version_info < (3, 6):
+
     def _utime(self, atime, mtime):
         os.utime(str(self), (atime, mtime), follow_symlinks=False)
+
+
 else:
+
     def _utime(self, atime, mtime):
         os.utime(self, (atime, mtime), follow_symlinks=False)
 
@@ -216,8 +219,11 @@ class PathLibConversionHelper(object):
             stream = sys.stdout
         for t in self._usage:
             if show_all or not all(t[3]):
-                print('{t[2]} [{t[0]}:{t[1]} / {count} / Path {t[3]}]'.format(
-                    count=self._usage[t][0], t=t))
+                print(
+                    '{t[2]} [{t[0]}:{t[1]} / {count} / Path {t[3]}]'.format(
+                        count=self._usage[t][0], t=t
+                    )
+                )
 
     def rename(self, old_name, new_name):
         """os.rename replacement that can handle Path argument"""
